#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-9xi9dLPfzpUAC9wwopDax7
key:                  coinbase-pro-0.9.3.2-9xi9dLPfzpUAC9wwopDax7
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  40a4ca309a5b45130745f69ddd869f12
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-9xi9dLPfzpUAC9wwopDax7
depends:
    HsOpenSSL-0.11.7.9-2TFNMc5AyRtLjQbBjXmfks
    aeson-2.2.1.0-B3EHpOrhFBKFg56QPA2Q3I
    aeson-casing-0.2.0.0-CE4Mmgc7J6v9CqZd3HEcfK
    async-2.2.6-Gml4H6UctygFSqCTsp1iZf base-4.18.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-9SM2uUyM5gx6YC1LxlyDGQ exceptions-0.10.7
    http-api-data-0.6.1-4DLSFxR866nKJGItovjPQc
    http-client-0.7.19-9meVfWioNG49hhaNpvORg0
    http-client-tls-0.3.6.4-64ZNym5SGVuSefUXbYwod
    http-streams-0.8.9.9-A6TiTG7eOXvKAVKPzwvlP4
    http-types-0.12.4-4tdX51H3YCXI63KUlr8q5w
    io-streams-1.5.2.2-7iCrmyDrvTv6PQN4mqwoVO
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    network-3.1.4.0-57XjnahcYfrBnbtgCzAhJP
    servant-0.20.3.0-5cFqVR8XZP97044O9hZ6Kl
    servant-client-0.20.3.0-9b9OE6FKtG78BqEekCcecx
    servant-client-core-0.20.3.0-53kjxzl0U52GFNzfDajf09
    tasty-1.5.2-Ecucfh1EfNvF5aNYdx3wDU
    tasty-hunit-0.10.2-DvT0nUZbfNP8apsjdHpvI7 text-2.0.2 time-1.12.2
    transformers-0.6.1.0 unagi-streams-0.2.7-2AP10Jj3e4Q1URapNCHsxc
    unordered-containers-0.2.20.1-24qNbjJ9xXJll0vtFCYfq
    uuid-1.3.16-E14zVMKNOKa6MWWZ9x240y
    vector-0.13.2.0-5hQDxYlIzjI43Z4IxwIpHc
    websockets-0.12.7.3-5MEYggazjCN7OO7PKjg0MW
    wuss-2.0.1.6-30DGluXCqoS9SpWSpCc9KG

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

